#  Copyright (C) 2023
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mike Orlov <m.orlov@abm-jsc.ru>
from logging import getLogger

from ._delete_mixin import _DeleteViewMixin
from .relation import RelationView

logger = getLogger(__name__)


class RelationDeleteView(_DeleteViewMixin, RelationView):
    pass
